@@ -59,6 +59,7 @@
 #include <libxfdashboard/enums.h>
 #include <libxfdashboard/application.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
 
 
 /* Define this class in GObject system */
@@ -345,9 +346,10 @@ static XfdashboardSearchViewProviderData* _xfdashboard_search_view_get_provider_
 	if(!container)
 	{
 		/* Container for requested child was not found */
-		g_debug("Did not find container for actor %p of type %s",
-					inChild,
-					G_OBJECT_TYPE_NAME(inChild));
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Did not find container for actor %p of type %s",
+							inChild,
+							G_OBJECT_TYPE_NAME(inChild));
 
 		return(NULL);
 	}
@@ -391,10 +393,11 @@ static void _xfdashboard_search_view_on_search_provider_registered(XfdashboardSe
 		data=_xfdashboard_search_view_provider_data_new(self, inProviderID);
 		priv->providers=g_list_append(priv->providers, data);
 
-		g_debug("Created search provider %s of type %s in %s",
-					xfdashboard_search_provider_get_name(data->provider),
-					G_OBJECT_TYPE_NAME(data->provider),
-					G_OBJECT_TYPE_NAME(self));
+		XFDASHBOARD_DEBUG(self, MISC,
+							"Created search provider %s of type %s in %s",
+							xfdashboard_search_provider_get_name(data->provider),
+							G_OBJECT_TYPE_NAME(data->provider),
+							G_OBJECT_TYPE_NAME(self));
 	}
 		else _xfdashboard_search_view_provider_data_unref(data);
 }
@@ -417,10 +420,11 @@ static void _xfdashboard_search_view_on_search_provider_unregistered(Xfdashboard
 	data=_xfdashboard_search_view_get_provider_data(self, inProviderID);
 	if(data)
 	{
-		g_debug("Unregistering search provider %s of type %s in %s",
-					xfdashboard_search_provider_get_name(data->provider),
-					G_OBJECT_TYPE_NAME(data->provider),
-					G_OBJECT_TYPE_NAME(self));
+		XFDASHBOARD_DEBUG(self, MISC,
+							"Unregistering search provider %s of type %s in %s",
+							xfdashboard_search_provider_get_name(data->provider),
+							G_OBJECT_TYPE_NAME(data->provider),
+							G_OBJECT_TYPE_NAME(self));
 
 		/* Find data of unregistered search provider in list of
 		 * active search providers to remove it from that list.
@@ -612,11 +616,12 @@ static void _xfdashboard_search_view_on_provider_container_destroyed(ClutterActo
 		 * new selection found and will be set.
 		 */
 		oldSelection=xfdashboard_focusable_get_selection(XFDASHBOARD_FOCUSABLE(self));
-		g_debug("Container of provider %s is destroyed but holds current selection %p of type %s - so selecting %p of type %s of provider %s",
-					providerData->provider ? G_OBJECT_TYPE_NAME(providerData->provider) : "<nil>",
-					oldSelection, oldSelection ? G_OBJECT_TYPE_NAME(oldSelection) : "<nil>",
-					newSelection, newSelection ? G_OBJECT_TYPE_NAME(newSelection) : "<nil>",
-					newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<nil>");
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Container of provider %s is destroyed but holds current selection %p of type %s - so selecting %p of type %s of provider %s",
+							providerData->provider ? G_OBJECT_TYPE_NAME(providerData->provider) : "<nil>",
+							oldSelection, oldSelection ? G_OBJECT_TYPE_NAME(oldSelection) : "<nil>",
+							newSelection, newSelection ? G_OBJECT_TYPE_NAME(newSelection) : "<nil>",
+							newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<nil>");
 
 		xfdashboard_focusable_set_selection(XFDASHBOARD_FOCUSABLE(self), newSelection);
 	}
@@ -847,10 +852,11 @@ static guint _xfdashboard_search_view_perform_search(XfdashboardSearchView *self
 		providerNewResultSet=xfdashboard_search_provider_get_result_set(providerData->provider,
 																		(const gchar**)inSearchTerms->termList,
 																		providerLastResultSet);
-		g_debug("Performed %s search at search provider %s and got %u result items",
-					canDoIncrementalSearch==TRUE ? "incremental" : "full",
-					G_OBJECT_TYPE_NAME(providerData->provider),
-					providerNewResultSet ? xfdashboard_search_result_set_get_size(providerNewResultSet) : 0);
+		XFDASHBOARD_DEBUG(self, MISC,
+							"Performed %s search at search provider %s and got %u result items",
+							canDoIncrementalSearch==TRUE ? "incremental" : "full",
+							G_OBJECT_TYPE_NAME(providerData->provider),
+							providerNewResultSet ? xfdashboard_search_result_set_get_size(providerNewResultSet) : 0);
 
 		/* Count number of results */
 		if(providerNewResultSet) numberResults+=xfdashboard_search_result_set_get_size(providerNewResultSet);
@@ -874,7 +880,10 @@ static guint _xfdashboard_search_view_perform_search(XfdashboardSearchView *self
 
 #ifdef DEBUG
 	/* Get time for this search for debug performance */
-	g_debug("Updating search for '%s' took %f seconds", inSearchTerms->termString, g_timer_elapsed(timer, NULL));
+	XFDASHBOARD_DEBUG(self, MISC,
+						"Updating search for '%s' took %f seconds",
+						inSearchTerms->termString,
+						g_timer_elapsed(timer, NULL));
 	g_timer_destroy(timer);
 #endif
 
@@ -904,9 +913,10 @@ static guint _xfdashboard_search_view_perform_search(XfdashboardSearchView *self
 
 			/* Set new selection */
 			xfdashboard_focusable_set_selection(XFDASHBOARD_FOCUSABLE(self), selection);
-			g_debug("Reselecting selectable item in direction %d at provider %s as old selection vanished",
-					reselectDirection,
-					xfdashboard_search_provider_get_name(reselectProvider->provider));
+			XFDASHBOARD_DEBUG(self, ACTOR,
+								"Reselecting selectable item in direction %d at provider %s as old selection vanished",
+								reselectDirection,
+								xfdashboard_search_provider_get_name(reselectProvider->provider));
 		}
 	}
 
@@ -1351,9 +1361,10 @@ static ClutterActor* _xfdashboard_search_view_focusable_find_selection(Xfdashboa
 			}
 		}
 
-		g_debug("No selection for %s, so select first selectable actor of provider %s",
-					G_OBJECT_TYPE_NAME(self),
-					newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"No selection for %s, so select first selectable actor of provider %s",
+							G_OBJECT_TYPE_NAME(self),
+							newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
 
 		return(newSelection);
 	}
@@ -1382,9 +1393,10 @@ static ClutterActor* _xfdashboard_search_view_focusable_find_selection(Xfdashboa
 			}
 		}
 
-		g_debug("First selection requested at %s, so select first selectable actor of provider %s",
-					G_OBJECT_TYPE_NAME(self),
-					newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"First selection requested at %s, so select first selectable actor of provider %s",
+							G_OBJECT_TYPE_NAME(self),
+							newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
 
 		return(newSelection);
 	}
@@ -1413,9 +1425,10 @@ static ClutterActor* _xfdashboard_search_view_focusable_find_selection(Xfdashboa
 			}
 		}
 
-		g_debug("Last selection requested at %s, so select last selectable actor of provider %s",
-					G_OBJECT_TYPE_NAME(self),
-					newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Last selection requested at %s, so select last selectable actor of provider %s",
+							G_OBJECT_TYPE_NAME(self),
+							newSelectionProvider && newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
 
 		return(newSelection);
 	}
@@ -1426,17 +1439,19 @@ static ClutterActor* _xfdashboard_search_view_focusable_find_selection(Xfdashboa
 	newSelectionProvider=_xfdashboard_search_view_get_provider_data_by_actor(self, inSelection);
 	if(!newSelectionProvider)
 	{
-		g_debug("Could not find provider for selection %p of type %s",
-					inSelection,
-					inSelection ? G_OBJECT_TYPE_NAME(inSelection) : "<nil>");
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Could not find provider for selection %p of type %s",
+							inSelection,
+							inSelection ? G_OBJECT_TYPE_NAME(inSelection) : "<nil>");
 		return(NULL);
 	}
 
 	currentProviderIter=g_list_find(priv->providers, newSelectionProvider);
 	if(!currentProviderIter)
 	{
-		g_debug("Could not find position of provider %s",
-					newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Could not find position of provider %s",
+							newSelectionProvider->provider ? G_OBJECT_TYPE_NAME(newSelectionProvider->provider) : "<unknown provider>");
 
 		/* Release allocated resources */
 		_xfdashboard_search_view_provider_data_unref(newSelectionProvider);
