@@ -39,6 +39,7 @@
 #include <libxfdashboard/stylable.h>
 #include <libxfdashboard/css-selector.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
 
 
 /* Define this class in GObject system */
@@ -123,12 +124,14 @@ static void _xfdashboard_theme_css_set_error(XfdashboardThemeCSS *self,
 static gchar* _xfdashboard_theme_css_resolve_at_identifier_internal(XfdashboardThemeCSS *self,
 																	GScanner *inScanner,
 																	GScanner *inScopeScanner,
-																	GList *inScopeSelectors);
+																	GList *inScopeSelectors,
+																	const gchar *inRecursionIdentifier);
 
 static gchar* _xfdashboard_theme_css_resolve_at_identifier_by_string(XfdashboardThemeCSS *self,
 																		const gchar *inValue,
 																		GScanner *inScopeScanner,
-																		GList *inScopeSelectors);
+																		GList *inScopeSelectors,
+																		const gchar *inRecursionIdentifier);
 
 /* Helper function to set up GError object in this parser */
 static void _xfdashboard_theme_css_set_error(XfdashboardThemeCSS *self,
@@ -915,7 +918,8 @@ static void _xfdashboard_theme_css_register_function(XfdashboardThemeCSS *self,
 static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *self,
 															GScanner *ioScanner,
 															GScanner *inScopeScanner,
-															GList *inScopeSelectors)
+															GList *inScopeSelectors,
+															const gchar *inRecursionIdentifier)
 {
 	XfdashboardThemeCSSPrivate				*priv;
 	GTokenType								token;
@@ -928,6 +932,7 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 
 	g_return_val_if_fail(XFDASHBOARD_IS_THEME_CSS(self), NULL);
 	g_return_val_if_fail(ioScanner, NULL);
+	g_return_val_if_fail(!inRecursionIdentifier || *inRecursionIdentifier, NULL);
 
 	priv=self->priv;
 
@@ -975,7 +980,9 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 		ioScanner->config=scannerConfig;
 
 		/* Function arguments must begin with '('. Check for it and parse function arguments ... */
-		g_debug("Fetching arguments to for calling function '%s'", identifier);
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Fetching arguments to for calling function '%s'",
+							identifier);
 
 		token=g_scanner_get_next_token(ioScanner);
 		if(token==G_TOKEN_LEFT_PAREN)
@@ -1002,7 +1009,8 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 							resolvedValue=_xfdashboard_theme_css_parse_at_identifier(self,
 																						ioScanner,
 																						inScopeScanner,
-																						inScopeSelectors);
+																						inScopeSelectors,
+																						inRecursionIdentifier);
 
 							/* Resolve resolved value to get final value */
 							if(resolvedValue)
@@ -1013,7 +1021,8 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 								finalResolvedValue=_xfdashboard_theme_css_resolve_at_identifier_by_string(self,
 																											resolvedValue,
 																											inScopeScanner,
-																											inScopeSelectors);
+																											inScopeSelectors,
+																											inRecursionIdentifier);
 
 								/* Release old value and set new one */
 								g_free(resolvedValue);
@@ -1028,10 +1037,11 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 								else
 								{
 									error=TRUE;
-									g_debug("Could not resolve '%s' for argument #%d of function '%s'",
-												orginalValue,
-												g_list_length(arguments),
-												identifier);
+									XFDASHBOARD_DEBUG(self, THEME,
+														"Could not resolve '%s' for argument #%d of function '%s'",
+														orginalValue,
+														g_list_length(arguments),
+														identifier);
 								}
 
 							/* Set new scanner config again to parse remaining arguments */
@@ -1058,9 +1068,10 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 						{
 							/* Add function argument to list of arguments */
 							arguments=g_list_append(arguments, arg);
-							g_debug("Added argument #%d: '%s'",
-										g_list_length(arguments),
-										arg);
+							XFDASHBOARD_DEBUG(self, THEME,
+												"Added argument #%d: '%s'",
+												g_list_length(arguments),
+												arg);
 
 							/* Prepare for next argument */
 							arg=NULL;
@@ -1141,9 +1152,10 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 			{
 				/* Add function argument to list of arguments */
 				arguments=g_list_append(arguments, arg);
-				g_debug("Added final argument #%d: '%s'",
-							g_list_length(arguments),
-							arg);
+				XFDASHBOARD_DEBUG(self, THEME,
+									"Added final argument #%d: '%s'",
+									g_list_length(arguments),
+									arg);
 
 				/* Does not make sense but just in case - prepare for next argument ;) */
 				arg=NULL;
@@ -1191,7 +1203,10 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 			/* Initialize for function call */
 			functionError=NULL;
 
-			g_debug("Calling registered function %s with %d arguments", identifier, g_list_length(arguments));
+			XFDASHBOARD_DEBUG(self, THEME,
+								"Calling registered function %s with %d arguments",
+								identifier,
+								g_list_length(arguments));
 			functionSuccess=(functionCallback)(self, identifier, arguments, &functionValue, &functionError);
 			if(functionSuccess)
 			{
@@ -1225,16 +1240,21 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 				g_value_unset(&stringValue);
 				g_value_unset(&functionValue);
 
-				g_debug("Calling function %s with %d arguments succeeded with result: %s", identifier, g_list_length(arguments), result);
+				XFDASHBOARD_DEBUG(self, THEME,
+									"Calling function %s with %d arguments succeeded with result: %s",
+									identifier,
+									g_list_length(arguments),
+									result);
 			}
 				else
 				{
 					gchar		*message;
 
-					g_debug("Calling function %s with %d arguments failed: %s",
-								identifier,
-								g_list_length(arguments),
-								(functionError && functionError->message) ? functionError->message : _("Unknown error"));
+					XFDASHBOARD_DEBUG(self, THEME,
+										"Calling function %s with %d arguments failed: %s",
+										identifier,
+										g_list_length(arguments),
+										(functionError && functionError->message) ? functionError->message : _("Unknown error"));
 
 					/* Set error message */
 					if(functionError && functionError->message)
@@ -1276,6 +1296,31 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 	 * through these selectors backwards (first in selectors of current file/scope
 	 * then all previous ones) to let last definition win.
 	 */
+	if(inRecursionIdentifier &&
+		g_strcmp0(identifier, inRecursionIdentifier)==0)
+	{
+		/* Identifier was unresolvable because of indefinite recursion,
+		 * so print error message and also a critical message.
+		 */
+		g_critical("Indefinte recursion of @-constant '%s' detected - aborting parsing", inRecursionIdentifier);
+
+		errorMessage=g_strdup_printf(_("Cannot resolve identifier '@%s' because of indefinite recursion"), identifier);
+		g_scanner_unexp_token(inScopeScanner,
+								G_TOKEN_ERROR,
+								NULL,
+								NULL,
+								NULL,
+								errorMessage,
+								FALSE);
+		g_free(errorMessage);
+
+		/* Release allocated resources */
+		g_free(identifier);
+
+		/* Identifier was unresolvable so return NULL */
+		return(NULL);
+	}
+
 	for(iter=g_list_last(inScopeSelectors); iter; iter=g_list_previous(iter))
 	{
 		selector=(XfdashboardThemeCSSSelector*)iter->data;
@@ -1333,18 +1378,20 @@ static gchar* _xfdashboard_theme_css_parse_at_identifier(XfdashboardThemeCSS *se
 static gchar* _xfdashboard_theme_css_resolve_at_identifier_internal(XfdashboardThemeCSS *self,
 																	GScanner *inScanner,
 																	GScanner *inScopeScanner,
-																	GList *inScopeSelectors)
+																	GList *inScopeSelectors,
+																	const gchar *inRecursionIdentifier)
 {
 	GTokenType		token;
 	gchar			*value;
-	gboolean		haveResolvedAtIdentifier;
+	gchar			*haveResolvedAtIdentifier;
 
 	g_return_val_if_fail(XFDASHBOARD_IS_THEME_CSS(self), NULL);
 	g_return_val_if_fail(inScanner, NULL);
 	g_return_val_if_fail(inScopeScanner, NULL);
+	g_return_val_if_fail(!inRecursionIdentifier || *inRecursionIdentifier, NULL);
 
 	/* Parse value and resolve '@' identifier */
-	haveResolvedAtIdentifier=FALSE;
+	haveResolvedAtIdentifier=NULL;
 	value=NULL;
 
 	token=g_scanner_get_next_token(inScanner);
@@ -1367,9 +1414,15 @@ static gchar* _xfdashboard_theme_css_resolve_at_identifier_internal(XfdashboardT
 					gchar		*constantValue;
 
 					/* Resolve value and append resolved value but stop parsing and return NULL
-					 * if unresolvable.
+					 * if unresolvable. Also remember '@' identifier we have resolved to get the
+					 * new value resolved.
 					 */
-					constantValue=_xfdashboard_theme_css_parse_at_identifier(self, inScanner, inScopeScanner, inScopeSelectors);
+					token=g_scanner_peek_next_token(inScanner);
+					if(token!=G_TOKEN_IDENTIFIER) return(NULL);
+
+					haveResolvedAtIdentifier=g_strdup(inScanner->next_value.v_identifier);
+
+					constantValue=_xfdashboard_theme_css_parse_at_identifier(self, inScanner, inScopeScanner, inScopeSelectors, inRecursionIdentifier);
 					if(!constantValue)
 					{
 						g_free(value);
@@ -1377,10 +1430,9 @@ static gchar* _xfdashboard_theme_css_resolve_at_identifier_internal(XfdashboardT
 					}
 
 					value=_xfdashboard_theme_css_append_string(value, constantValue);
-					g_free(constantValue);
 
-					/* Set flag that we have resolved an '@' identifier to get the new value resolved */
-					haveResolvedAtIdentifier=TRUE;
+					/* Release allocated resources */
+					g_free(constantValue);
 				}
 					/* ... otherwise just add character to value */
 					else value=_xfdashboard_theme_css_append_char(value, inScanner->value.v_char);
@@ -1406,16 +1458,29 @@ static gchar* _xfdashboard_theme_css_resolve_at_identifier_internal(XfdashboardT
 		/* Call ourselve recursive (via _xfdashboard_theme_css_resolve_at_identifier_by_string)
 		 * to resolve any '@' identifier which might be in value resolved this time.
 		 */
-		g_debug("Resolving css value '%s'", value);
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Resolving css value '%s' because of constant identifier '%s'",
+							value,
+							haveResolvedAtIdentifier);
+
 		resolvedValue=_xfdashboard_theme_css_resolve_at_identifier_by_string(self,
 																				value,
 																				inScopeScanner,
-																				inScopeSelectors);
-		g_debug("Resolved css value '%s' to '%s' recursively", value, resolvedValue);
+																				inScopeSelectors,
+																				haveResolvedAtIdentifier);
+
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Resolved css value '%s' to '%s' recursively because of constant identifier '%s'",
+							value,
+							resolvedValue,
+							haveResolvedAtIdentifier);
 
 		/* Release old value and new one */
 		g_free(value);
 		value=resolvedValue;
+
+		/* Release allocated resources */
+		g_free(haveResolvedAtIdentifier);
 	}
 
 	/* Return resolved value */
@@ -1425,14 +1490,39 @@ static gchar* _xfdashboard_theme_css_resolve_at_identifier_internal(XfdashboardT
 static gchar* _xfdashboard_theme_css_resolve_at_identifier_by_string(XfdashboardThemeCSS *self,
 																		const gchar *inText,
 																		GScanner *inScopeScanner,
-																		GList *inScopeSelectors)
+																		GList *inScopeSelectors,
+																		const gchar *inRecursionIdentifier)
 {
-	GScanner	*scanner;
-	gchar		*value;
+	GScanner		*scanner;
+	gchar			*value;
+	static gint		callDepth=0;
 
 	g_return_val_if_fail(XFDASHBOARD_IS_THEME_CSS(self), NULL);
 	g_return_val_if_fail(inScopeScanner, NULL);
 	g_return_val_if_fail(inText, NULL);
+	g_return_val_if_fail(!inRecursionIdentifier || *inRecursionIdentifier, NULL);
+
+	/* Increment call depth and check if it is too deep now to avoid recursive
+	 * resolves of '@' identifier definitions.
+	 */
+	callDepth++;
+	if(callDepth>128)
+	{
+		gchar		*error;
+
+		error=g_strdup_printf(_("Possible recursion detected because call depth is too deep while resolving '%s'"),
+								inText);
+		g_scanner_unexp_token(inScopeScanner,
+								G_TOKEN_ERROR,
+								NULL,
+								NULL,
+								NULL,
+								error,
+								FALSE);
+		g_free(error);
+
+		return(NULL);
+	}
 
 	/* Create scanner to resolve value of '@' identifier */
 	scanner=g_scanner_new(NULL);
@@ -1461,11 +1551,15 @@ static gchar* _xfdashboard_theme_css_resolve_at_identifier_by_string(Xfdashboard
 	value=_xfdashboard_theme_css_resolve_at_identifier_internal(self,
 																scanner,
 																inScopeScanner,
-																inScopeSelectors);
+																inScopeSelectors,
+																inRecursionIdentifier);
 
 	/* Destroy scanner */
 	g_scanner_destroy(scanner);
 
+	/* Decrement call depth counter again */
+	callDepth--;
+
 	/* Return resolved '@' identifier which may be NULL in case of error */
 	return(value);
 }
@@ -1621,12 +1715,18 @@ static GTokenType _xfdashboard_theme_css_parse_css_key_value(XfdashboardThemeCSS
 		gchar		*resolvedValue;
 
 		/* Resolve value */
-		g_debug("Resolving css value '%s'", *outValue);
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Resolving css value '%s'",
+							*outValue);
 		resolvedValue=_xfdashboard_theme_css_resolve_at_identifier_by_string(self,
 																				*outValue,
 																				inScanner,
-																				inScopeSelectors);
-		g_debug("Resolved css value '%s' to '%s'", *outValue, resolvedValue);
+																				inScopeSelectors,
+																				NULL);
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Resolved css value '%s' to '%s'",
+							*outValue,
+							resolvedValue);
 
 		/* Release old value and set new one */
 		g_free(*outValue);
@@ -1853,10 +1953,11 @@ static GTokenType _xfdashboard_theme_css_command_import(XfdashboardThemeCSS *sel
 			tempFilename=g_build_filename(cssPath, filename, NULL);
 			if(g_file_test(tempFilename, G_FILE_TEST_EXISTS))
 			{
-				g_debug("Resolved relative path '%s' to import to '%s' which is relative to current css file '%s'.",
-							filename,
-							tempFilename,
-							inScanner->input_name);
+				XFDASHBOARD_DEBUG(self, THEME,
+									"Resolved relative path '%s' to import to '%s' which is relative to current css file '%s'.",
+									filename,
+									tempFilename,
+									inScanner->input_name);
 
 				g_free(filename);
 				filename=g_strdup(tempFilename);
@@ -1875,10 +1976,11 @@ static GTokenType _xfdashboard_theme_css_command_import(XfdashboardThemeCSS *sel
 		{
 			tempFilename=g_build_filename(priv->themePath, filename, NULL);
 
-			g_debug("Resolved relative path '%s' to import to '%s' which is relative to theme path '%s'.",
-						filename,
-						tempFilename,
-						priv->themePath);
+			XFDASHBOARD_DEBUG(self, THEME,
+								"Resolved relative path '%s' to import to '%s' which is relative to theme path '%s'.",
+								filename,
+								tempFilename,
+								priv->themePath);
 
 			g_free(filename);
 			filename=g_strdup(tempFilename);
@@ -1922,7 +2024,9 @@ static GTokenType _xfdashboard_theme_css_command_import(XfdashboardThemeCSS *sel
 		return(G_TOKEN_ERROR);
 	}
 
-	g_debug("Imported CSS file '%s'", filename);
+	XFDASHBOARD_DEBUG(self, THEME,
+						"Imported CSS file '%s'",
+						filename);
 
 	/* Correct line offset */
 	priv->offsetLine-=oldLineOffset;
@@ -2616,19 +2720,21 @@ gboolean xfdashboard_theme_css_add_file(XfdashboardThemeCSS *self,
 	if(selectors)
 	{
 		priv->selectors=g_list_concat(priv->selectors, selectors);
-		g_debug("Successfully parsed '%s' and added %d selectors - total %d selectors",
-					inPath,
-					g_list_length(selectors),
-					g_list_length(priv->selectors));
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Successfully parsed '%s' and added %d selectors - total %d selectors",
+							inPath,
+							g_list_length(selectors),
+							g_list_length(priv->selectors));
 	}
 
 	if(styles)
 	{
 		priv->styles=g_list_concat(priv->styles, styles);
-		g_debug("Successfully parsed '%s' and added %d styles - total %d styles",
-					inPath,
-					g_list_length(styles),
-					g_list_length(priv->styles));
+		XFDASHBOARD_DEBUG(self, THEME,
+							"Successfully parsed '%s' and added %d styles - total %d styles",
+							inPath,
+							g_list_length(styles),
+							g_list_length(priv->styles));
 	}
 
 	/* Release allocated resources */
@@ -2674,7 +2780,9 @@ GHashTable* xfdashboard_theme_css_get_properties(XfdashboardThemeCSS *self,
 									(styleID) ? styleID : "",
 									(stylePseudoClasses) ? ":" : "",
 									(stylePseudoClasses) ? stylePseudoClasses : "");
-	g_debug("Looking up matches for %s ", styleSelector);
+	XFDASHBOARD_DEBUG(self, STYLE,
+						"Looking up matches for %s ",
+						styleSelector);
 
 	timer=g_timer_new();
 #endif
@@ -2688,7 +2796,7 @@ GHashTable* xfdashboard_theme_css_get_properties(XfdashboardThemeCSS *self,
 		selector=(XfdashboardThemeCSSSelector*)entry->data;
 		if(selector->type==XFDASHBOARD_THEME_CSS_SELECTOR_TYPE_SELECTOR)
 		{
-			score=xfdashboard_css_selector_score_matching_stylable_node(selector->selector, inStylable);
+			score=xfdashboard_css_selector_score(selector->selector, inStylable);
 			if(score>=0)
 			{
 				match=g_slice_new(XfdashboardThemeCSSSelectorMatch);
@@ -2728,10 +2836,11 @@ GHashTable* xfdashboard_theme_css_get_properties(XfdashboardThemeCSS *self,
 	g_list_free(matches);
 
 #ifdef DEBUG
-	g_debug("Found %u properties for %s in %f seconds" ,
-				g_hash_table_size(result),
-				styleSelector,
-				g_timer_elapsed(timer, NULL));
+	XFDASHBOARD_DEBUG(self, STYLE,
+						"Found %u properties for %s in %f seconds" ,
+						g_hash_table_size(result),
+						styleSelector,
+						g_timer_elapsed(timer, NULL));
 	g_timer_destroy(timer);
 	g_free(styleSelector);
 #endif
