@@ -44,7 +44,9 @@
 #include <libxfdashboard/marshal.h>
 #include <libxfdashboard/enums.h>
 #include <libxfdashboard/stage-interface.h>
+#include <libxfdashboard/live-workspace.h>
 #include <libxfdashboard/compat.h>
+#include <libxfdashboard/debug.h>
 
 
 /* Define this class in GObject system */
@@ -207,20 +209,24 @@ static gboolean _xfdashboard_windows_view_update_stage_and_monitor(XfdashboardWi
 static gboolean _xfdashboard_windows_view_is_visible_window(XfdashboardWindowsView *self,
 																XfdashboardWindowTrackerWindow *inWindow)
 {
-	XfdashboardWindowsViewPrivate		*priv;
+	XfdashboardWindowsViewPrivate			*priv;
+	XfdashboardWindowTrackerWindowState		state;
 
 	g_return_val_if_fail(XFDASHBOARD_IS_WINDOWS_VIEW(self), FALSE);
 	g_return_val_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW(inWindow), FALSE);
 
 	priv=self->priv;
 
+	/* Get state of window */
+	state=xfdashboard_window_tracker_window_get_state(inWindow);
+
 	/* Determine if windows should be shown depending on its state, size and position */
-	if(xfdashboard_window_tracker_window_is_skip_pager(inWindow))
+	if(state & XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_PAGER)
 	{
 		return(FALSE);
 	}
 
-	if(xfdashboard_window_tracker_window_is_skip_tasklist(inWindow))
+	if(state & XFDASHBOARD_WINDOW_TRACKER_WINDOW_STATE_SKIP_TASKLIST)
 	{
 		return(FALSE);
 	}
@@ -403,23 +409,24 @@ static void _xfdashboard_windows_view_move_live_to_view(XfdashboardWindowsView *
 	sourceMonitor=xfdashboard_window_tracker_window_get_monitor(window);
 	targetMonitor=priv->currentMonitor;
 
-	g_debug("Moving window '%s' from %s-monitor %d to %s-monitor %d and from workspace '%s' (%d) to '%s' (%d)",
-				xfdashboard_window_tracker_window_get_title(window),
-				xfdashboard_window_tracker_monitor_is_primary(sourceMonitor) ? "primary" : "secondary",
-				xfdashboard_window_tracker_monitor_get_number(sourceMonitor),
-				xfdashboard_window_tracker_monitor_is_primary(targetMonitor) ? "primary" : "secondary",
-				xfdashboard_window_tracker_monitor_get_number(targetMonitor),
-				xfdashboard_window_tracker_workspace_get_name(sourceWorkspace),
-				xfdashboard_window_tracker_workspace_get_number(sourceWorkspace),
-				xfdashboard_window_tracker_workspace_get_name(targetWorkspace),
-				xfdashboard_window_tracker_workspace_get_number(targetWorkspace));
+	XFDASHBOARD_DEBUG(self, ACTOR,
+						"Moving window '%s' from %s-monitor %d to %s-monitor %d and from workspace '%s' (%d) to '%s' (%d)",
+						xfdashboard_window_tracker_window_get_name(window),
+						xfdashboard_window_tracker_monitor_is_primary(sourceMonitor) ? "primary" : "secondary",
+						xfdashboard_window_tracker_monitor_get_number(sourceMonitor),
+						xfdashboard_window_tracker_monitor_is_primary(targetMonitor) ? "primary" : "secondary",
+						xfdashboard_window_tracker_monitor_get_number(targetMonitor),
+						xfdashboard_window_tracker_workspace_get_name(sourceWorkspace),
+						xfdashboard_window_tracker_workspace_get_number(sourceWorkspace),
+						xfdashboard_window_tracker_workspace_get_name(targetWorkspace),
+						xfdashboard_window_tracker_workspace_get_number(targetWorkspace));
 
 	/* Get position and size of window to move */
-	xfdashboard_window_tracker_window_get_position_size(window,
-														&oldWindowX,
-														&oldWindowY,
-														&oldWindowWidth,
-														&oldWindowHeight);
+	xfdashboard_window_tracker_window_get_geometry(window,
+													&oldWindowX,
+													&oldWindowY,
+													&oldWindowWidth,
+													&oldWindowHeight);
 
 	/* Calculate source x and y coordinate relative to monitor size in percent */
 	xfdashboard_window_tracker_monitor_get_geometry(sourceMonitor,
@@ -443,23 +450,25 @@ static void _xfdashboard_windows_view_move_live_to_view(XfdashboardWindowsView *
 	if(!xfdashboard_window_tracker_workspace_is_equal(sourceWorkspace, targetWorkspace))
 	{
 		xfdashboard_window_tracker_window_move_to_workspace(window, targetWorkspace);
-		g_debug("Moved window '%s' from workspace '%s' (%d) to '%s' (%d)",
-					xfdashboard_window_tracker_window_get_title(window),
-					xfdashboard_window_tracker_workspace_get_name(sourceWorkspace),
-					xfdashboard_window_tracker_workspace_get_number(sourceWorkspace),
-					xfdashboard_window_tracker_workspace_get_name(targetWorkspace),
-					xfdashboard_window_tracker_workspace_get_number(targetWorkspace));
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Moved window '%s' from workspace '%s' (%d) to '%s' (%d)",
+							xfdashboard_window_tracker_window_get_name(window),
+							xfdashboard_window_tracker_workspace_get_name(sourceWorkspace),
+							xfdashboard_window_tracker_workspace_get_number(sourceWorkspace),
+							xfdashboard_window_tracker_workspace_get_name(targetWorkspace),
+							xfdashboard_window_tracker_workspace_get_number(targetWorkspace));
 	}
 
 	/* Move window to new position */
 	xfdashboard_window_tracker_window_move(window, newWindowX, newWindowY);
-	g_debug("Moved window '%s' from [%d,%d] at monitor [%d,%d x %d,%d] to [%d,%d] at monitor [%d,%d x %d,%d] (relative x=%.2f, y=%.2f)",
-				xfdashboard_window_tracker_window_get_title(window),
-				oldWindowX, oldWindowY,
-				oldMonitorX, oldMonitorY, oldMonitorWidth, oldMonitorHeight,
-				newWindowX, newWindowY,
-				newMonitorX, newMonitorY, newMonitorWidth, newMonitorHeight,
-				relativeX, relativeY);
+	XFDASHBOARD_DEBUG(self, ACTOR,
+						"Moved window '%s' from [%d,%d] at monitor [%d,%d x %d,%d] to [%d,%d] at monitor [%d,%d x %d,%d] (relative x=%.2f, y=%.2f)",
+						xfdashboard_window_tracker_window_get_name(window),
+						oldWindowX, oldWindowY,
+						oldMonitorX, oldMonitorY, oldMonitorWidth, oldMonitorHeight,
+						newWindowX, newWindowY,
+						newMonitorX, newMonitorY, newMonitorWidth, newMonitorHeight,
+						relativeX, relativeY);
 }
 
 /* Drag of an actor to this view as drop target begins */
@@ -481,19 +490,33 @@ static gboolean _xfdashboard_windows_view_on_drop_begin(XfdashboardWindowsView *
 	dragSource=xfdashboard_drag_action_get_source(inDragAction);
 	draggedActor=xfdashboard_drag_action_get_actor(inDragAction);
 
-	/* Check if we can handle dragged actor from given source */
+	/* We can handle dragged actor if it is an application button and its source
+	 * is quicklaunch.
+	 */
 	if(XFDASHBOARD_IS_QUICKLAUNCH(dragSource) &&
 		XFDASHBOARD_IS_APPLICATION_BUTTON(draggedActor))
 	{
 		canHandle=TRUE;
 	}
 
+	/* We can handle dragged actor if it is a live window and its source
+	 * is windows view.
+	 */
 	if(XFDASHBOARD_IS_WINDOWS_VIEW(dragSource) &&
 		XFDASHBOARD_IS_LIVE_WINDOW(draggedActor))
 	{
 		canHandle=TRUE;
 	}
 
+	/* We can handle dragged actor if it is a live window and its source
+	 * is a live workspace
+	 */
+	if(XFDASHBOARD_IS_LIVE_WORKSPACE(dragSource) &&
+		XFDASHBOARD_IS_LIVE_WINDOW_SIMPLE(draggedActor))
+	{
+		canHandle=TRUE;
+	}
+
 	/* Return TRUE if we can handle dragged actor in this drop target
 	 * otherwise FALSE
 	 */
@@ -540,7 +563,7 @@ static void _xfdashboard_windows_view_on_drop_drop(XfdashboardWindowsView *self,
 		XFDASHBOARD_IS_LIVE_WINDOW(draggedActor))
 	{
 		XfdashboardWindowsView			*sourceWindowsView;
-		XfdashboardLiveWindow			*liveWindow;
+		XfdashboardLiveWindow			*liveWindowActor;
 
 		/* Get source windows view */
 		sourceWindowsView=XFDASHBOARD_WINDOWS_VIEW(dragSource);
@@ -550,17 +573,54 @@ static void _xfdashboard_windows_view_on_drop_drop(XfdashboardWindowsView *self,
 		 */
 		if(sourceWindowsView==self)
 		{
-			g_message("Will not handle drop of %s at %s because source and target are the same.",
+			XFDASHBOARD_DEBUG(self, ACTOR,
+						"Will not handle drop of %s at %s because source and target are the same.",
 						G_OBJECT_TYPE_NAME(draggedActor),
 						G_OBJECT_TYPE_NAME(dragSource));
 			return;
 		}
 
 		/* Get dragged window */
-		liveWindow=XFDASHBOARD_LIVE_WINDOW(draggedActor);
+		liveWindowActor=XFDASHBOARD_LIVE_WINDOW(draggedActor);
 
-		/* Move window to monitor of this window view */
-		_xfdashboard_windows_view_move_live_to_view(self, liveWindow);
+		/* Move dragged window to monitor of this window view */
+		_xfdashboard_windows_view_move_live_to_view(self, liveWindowActor);
+
+		/* Drop action handled so return here */
+		return;
+	}
+
+	/* Handle drop of an window from a live workspace */
+	if(XFDASHBOARD_IS_LIVE_WORKSPACE(dragSource) &&
+		XFDASHBOARD_IS_LIVE_WINDOW_SIMPLE(draggedActor))
+	{
+		XfdashboardLiveWorkspace			*sourceLiveWorkspace;
+		XfdashboardWindowTrackerWorkspace*	sourceWorkspace;
+		XfdashboardLiveWindowSimple			*liveWindowActor;
+		XfdashboardWindowTrackerWindow		*window;
+
+		/* Get source live workspace and its workspace */
+		sourceLiveWorkspace=XFDASHBOARD_LIVE_WORKSPACE(dragSource);
+		sourceWorkspace=xfdashboard_live_workspace_get_workspace(sourceLiveWorkspace);
+
+		/* Do nothing if source and destination workspaces are the same as nothing
+		 * is to do in this case.
+		 */
+		if(xfdashboard_window_tracker_workspace_is_equal(sourceWorkspace, priv->workspace))
+		{
+			XFDASHBOARD_DEBUG(self, ACTOR,
+						"Will not handle drop of %s at %s because source and target workspaces are the same.",
+						G_OBJECT_TYPE_NAME(draggedActor),
+						G_OBJECT_TYPE_NAME(dragSource));
+			return;
+		}
+
+		/* Get dragged window */
+		liveWindowActor=XFDASHBOARD_LIVE_WINDOW_SIMPLE(draggedActor);
+		window=xfdashboard_live_window_simple_get_window(liveWindowActor);
+
+		/* Move dragged window to workspace of this window view */
+		xfdashboard_window_tracker_window_move_to_workspace(window, priv->workspace);
 
 		/* Drop action handled so return here */
 		return;
@@ -952,7 +1012,7 @@ static XfdashboardLiveWindow* _xfdashboard_windows_view_create_actor(Xfdashboard
 	/* Check if window opened is a stage window */
 	if(xfdashboard_window_tracker_window_is_stage(inWindow))
 	{
-		g_debug("Will not create live-window actor for stage window.");
+		XFDASHBOARD_DEBUG(self, ACTOR, "Will not create live-window actor for stage window.");
 		return(NULL);
 	}
 
@@ -1053,9 +1113,10 @@ static gboolean _xfdashboard_windows_view_on_scroll_event(ClutterActor *inActor,
 
 		/* Unhandled directions */
 		default:
-			g_debug("Cannot handle scroll direction %d in %s",
-						clutter_event_get_scroll_direction(inEvent),
-						G_OBJECT_TYPE_NAME(self));
+			XFDASHBOARD_DEBUG(self, ACTOR,
+								"Cannot handle scroll direction %d in %s",
+								clutter_event_get_scroll_direction(inEvent),
+								G_OBJECT_TYPE_NAME(self));
 			return(CLUTTER_EVENT_PROPAGATE);
 	}
 
@@ -1161,7 +1222,7 @@ static gboolean _xfdashboard_windows_view_window_close(XfdashboardWindowsView *s
 	/* Check if a window is currenly selected */
 	if(!priv->selectedItem)
 	{
-		g_debug("No window to close is selected.");
+		XFDASHBOARD_DEBUG(self, ACTOR, "No window to close is selected.");
 		return(CLUTTER_EVENT_STOP);
 	}
 
@@ -1510,10 +1571,11 @@ static ClutterActor* _xfdashboard_windows_view_focusable_find_selection(Xfdashbo
 		newSelection=clutter_actor_get_first_child(CLUTTER_ACTOR(self));
 
 		valueName=xfdashboard_get_enum_value_name(XFDASHBOARD_TYPE_SELECTION_TARGET, inDirection);
-		g_debug("No selection at %s, so select first child %s for direction %s",
-				G_OBJECT_TYPE_NAME(self),
-				newSelection ? G_OBJECT_TYPE_NAME(newSelection) : "<nil>",
-				valueName);
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"No selection at %s, so select first child %s for direction %s",
+							G_OBJECT_TYPE_NAME(self),
+							newSelection ? G_OBJECT_TYPE_NAME(newSelection) : "<nil>",
+							valueName);
 		g_free(valueName);
 
 		return(newSelection);
@@ -1651,11 +1713,12 @@ static ClutterActor* _xfdashboard_windows_view_focusable_find_selection(Xfdashbo
 	if(newSelection) selection=newSelection;
 
 	/* Return new selection found */
-	g_debug("Selecting %s at %s for current selection %s in direction %u",
-			selection ? G_OBJECT_TYPE_NAME(selection) : "<nil>",
-			G_OBJECT_TYPE_NAME(self),
-			inSelection ? G_OBJECT_TYPE_NAME(inSelection) : "<nil>",
-			inDirection);
+	XFDASHBOARD_DEBUG(self, ACTOR,
+						"Selecting %s at %s for current selection %s in direction %u",
+						selection ? G_OBJECT_TYPE_NAME(selection) : "<nil>",
+						G_OBJECT_TYPE_NAME(self),
+						inSelection ? G_OBJECT_TYPE_NAME(inSelection) : "<nil>",
+						inDirection);
 
 	return(selection);
 }
@@ -2039,7 +2102,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, window_close),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2053,7 +2116,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_show_numbers),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2067,7 +2130,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_hide_numbers),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2081,7 +2144,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_one),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2095,7 +2158,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_two),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2109,7 +2172,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_three),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2123,7 +2186,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_four),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2137,7 +2200,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_five),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2151,7 +2214,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_six),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2165,7 +2228,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_seven),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2179,7 +2242,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_eight),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2193,7 +2256,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_nine),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
@@ -2207,7 +2270,7 @@ static void xfdashboard_windows_view_class_init(XfdashboardWindowsViewClass *kla
 						G_STRUCT_OFFSET(XfdashboardWindowsViewClass, windows_activate_window_ten),
 						g_signal_accumulator_true_handled,
 						NULL,
-						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_OBJECT,
+						_xfdashboard_marshal_BOOLEAN__OBJECT_STRING_BOXED,
 						G_TYPE_BOOLEAN,
 						3,
 						XFDASHBOARD_TYPE_FOCUSABLE,
